@@ -10,10 +10,11 @@ use HTML::Selector::XPath qw(
 use Scalar::Util qw(
     blessed
     reftype
+    weaken
 );
 use XML::LibXML;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # default arguments for XML::LibXML
 my $default_libxml_args = {
@@ -93,15 +94,20 @@ $new_X = sub {
     # self must be a hash ref that includes a XML::LibXML object
     return $empty_x unless eval { $self->{_xml} };
 
-    my $X;
+    # need to jump through some hoops here to avoid creating
+    # a circular ref.  We can't have $X getting captured in its
+    # own closure, but we need to know the scalar value of $X, so
+    # create $Y, then assign the scalar value of $X to $Y after creating
+    # $X
+    my $Y;
     # HTML::Xit instance
-    $X = sub {
+    my $X = sub {
         my($select) = @_;
         # if we are passed a self-reference then
         # return our hidden instance variable
         return $self
             if ref $select
-            and $select eq $X;
+            and $select eq $Y;
 
         my $xml = $self->{_xml};
         # else create a new instance
@@ -127,7 +133,7 @@ $new_X = sub {
         else {
             # generate xpath from CSS selector using HTML::Selector::XPath
             my $xpath = selector_to_xpath($select)
-                or return $X;
+                or return $empty_x;
             # set the current xml context as the result of the xpath selection
             $self->{_xml} = $xml->find('.'.$xpath);
         }
@@ -135,7 +141,11 @@ $new_X = sub {
         return $new_X->($self);
     };
 
-    return bless($X, __PACKAGE__);
+    bless($X, __PACKAGE__);
+    # store scalar value of $X without creating another ref
+    $Y = "$X";
+    # return blessed sub ref
+    return $X;
 };
 
 # each
@@ -719,18 +729,18 @@ HTML::Xit - XML/HTML DOM Manipulation with CSS Selectors
 
 =head1 SYNOPSIS
 
-my $X = HTML::Xit->new("http://mysite.com/mydoc.html");
+    my $X = HTML::Xit->new("http://mysite.com/mydoc.html");
 
-$X->("a")->each( sub {
-    my($X) = @_;
+    $X->("a")->each( sub {
+        my($X) = @_;
 
-    print $X->attr("href");
-    print $X->text;
-} );
+        print $X->attr("href");
+        print $X->text;
+    } );
 
-$X->(".a")->addClass("b c d")->removeClass("c e")->toggleClass("b a");
+    $X->(".a")->addClass("b c d")->removeClass("c e")->toggleClass("b a");
 
-print $X->("<a>")->attr("href", "http://mysite.com")->text("My Site")->html;
+    print $X->("<a>")->attr("href", "http://mysite.com")->text("My Site")->html;
 
 =head1 DESCRIPTION
 
